@@ -9,9 +9,9 @@ FileName : __init__.py.py
 Software : PyCharm
 """
 __title__ = 'api2case'
-__description__ = 'Convert Swagger API to YAML testcase for jixing_test_frame'
+__description__ = '转换Swagger API为极星测试框架的YAML测试用例'
 __url__ = 'https://github.com/CaptainJi/api2case'
-__version__ = '0.1.17'
+__version__ = '0.1.18'
 __author__ = 'Captain Ji'
 __author_email__ = 'qing.ji@extremevision.com.cn'
 __license__ = 'Apache-2.0'
