@@ -24,17 +24,17 @@ if len(sys.argv) == 1:
     sys.argv.append('--help')
 
 parser = argparse.ArgumentParser(description=__description__)
-parser.add_argument('-v', '--version', version=version, help="显示版本")
-parser.add_argument('-u', '--url', type=str, help='swagger api地址（必填)', required=True)
-parser.add_argument('-U', '--username', default=None, type=str, help='swagger用户名')
-parser.add_argument('-P', '--password', default=None, type=str, help='swagger密码')
-parser.add_argument('-p', '--path', default=None, type=str, help='api路径，用于单独转换指定api')
+parser.add_argument('-v', '--version', help="显示版本")
+parser.add_argument('-u', '--url', type=str, help='swagger API接口文档地址（必填)', required=True)
+parser.add_argument('-n', '--username', default=None, type=str, help='swagger用户名')
+parser.add_argument('-w', '--password', default=None, type=str, help='swagger密码')
+parser.add_argument('-p', '--path', default=None, type=str, help='API路径，用于单独转换指定API')
 
 
 def main():
     args = parser.parse_args()
     if args.version:
-        logger.info("{}".format(version))
+        logger.info(f"{version}")
         exit(0)
     arguments = parser.parse_args()
     if not arguments.url:
